==> haskell-asn1-parse-0.9.5-330-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-JxVmaw0fG0cItL6FvzXVER
key:                  asn1-parse-0.9.5-JxVmaw0fG0cItL6FvzXVER
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  7d20ae35f75359af108f6b99acebfa79
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-JxVmaw0fG0cItL6FvzXVER
depends:
    asn1-encoding-0.9.6-6y79kc7T5Jj8rPAYFSYa7j
    asn1-types-0.3.4-DLQePJbkxMJ6nn5oXJ6XQb base-4.18.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.5-331-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-5BFYnl436C293MX5KdRhqg
key:                  asn1-parse-0.9.5-5BFYnl436C293MX5KdRhqg
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  ccedacb4d567ecef1df0964c3e3750e0
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-parse
hs-libraries:         HSasn1-parse-0.9.5-5BFYnl436C293MX5KdRhqg
depends:
    asn1-encoding-0.9.6-DFd7WnxxyUhJe90PepzNNG
    asn1-types-0.3.4-2nhBP7nBQPxDHtTmBg5BVh base-4.18.2.1
    bytestring-0.11.5.3

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
